@@ -1,4 +1,4 @@
-#!/usr/bin/ruby
+#!/usr/bin/ruby1.8
 
 =begin
   po2ul - generate a sorted list of unicode codepoint used in po files.
@@ -8,7 +8,7 @@
   Depends: ruby (>= 1.8), libgettext-ruby1.8
 =end
 
-require 'gettext/rmsgfmt'
+require 'gettext/tools/rmsgfmt'
 require 'iconv'
 include GetText
 
